"use strict";
// *******************************************************************************
//  * Copyright 2023 Adobe
//  *
//  * Licensed under the Apache License, Version 2.0 (the “License”);
//  * you may not use this file except in compliance with the License.
//  * You may obtain a copy of the License at
//  *
//  *     http://www.apache.org/licenses/LICENSE-2.0
//  *
//  * Unless required by applicable law or agreed to in writing, software
//  * distributed under the License is distributed on an “AS IS” BASIS,
//  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  * See the License for the specific language governing permissions and
//  * limitations under the License.
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccordionContext = void 0;
//  *  The BEM markup is as per the AEM core form components guidelines.
//  * LINK- https://github.com/adobe/aem-core-forms-components/blob/master/ui.af.apps/src/main/content/jcr_root/apps/core/fd/components/form/accordion/v1/accordion/accordion.html
//  ******************************************************************************
const react_1 = __importStar(require("react"));
const withRuleEngine_1 = require("../../utils/withRuleEngine");
const Item_1 = __importDefault(require("./Item"));
const RepeatableItem_1 = __importDefault(require("./RepeatableItem"));
const LabelWithDescription_1 = __importDefault(require("../common/LabelWithDescription"));
exports.AccordionContext = (0, react_1.createContext)('');
const Accordion = (props) => {
    const { items, id, label, visible, enabled, appliedCssClassNames } = props;
    const { v: visibleItems } = items.reduce(({ v }, item) => {
        const isVisible = item.visible === true;
        return {
            v: isVisible ? v.concat([item]) : v
        };
    }, { v: [] });
    const firstItem = visibleItems[0] || {};
    // for active first item
    let panelId = firstItem?.type === 'array' ? firstItem?.items[0]?.id : firstItem?.id;
    const [activePanel, setActivePanel] = (0, react_1.useState)(panelId);
    const handleToggle = (id) => {
        setActivePanel(id === activePanel ? null : id);
    };
    return (react_1.default.createElement("div", { className: `cmp-accordion ${appliedCssClassNames || ''}`, "data-cmp-is": "adaptiveFormAccordion", "data-cmp-single-expansion": "true", "data-placeholder-text": "false", "data-cmp-visible": visible, "data-cmp-enabled": enabled },
        react_1.default.createElement(LabelWithDescription_1.default, { bemBlock: 'cmp-accordion', label: label, id: id, tooltip: props.tooltip, description: props.description }),
        react_1.default.createElement(exports.AccordionContext.Provider, { value: { onToggle: handleToggle, activePanel: activePanel } }, visibleItems?.map((item) => {
            return item?.type === 'array' ? react_1.default.createElement(RepeatableItem_1.default, { ...item, key: `${item.id}-item` }) : react_1.default.createElement(Item_1.default, { ...item, key: `${item.id}-item` });
        }))));
};
exports.default = (0, withRuleEngine_1.withRuleEnginePanel)(Accordion);
