"use strict";
// *******************************************************************************
//  * Copyright 2023 Adobe
//  *
//  * Licensed under the Apache License, Version 2.0 (the “License”);
//  * you may not use this file except in compliance with the License.
//  * You may obtain a copy of the License at
//  *
//  *     http://www.apache.org/licenses/LICENSE-2.0
//  *
//  * Unless required by applicable law or agreed to in writing, software
//  * distributed under the License is distributed on an “AS IS” BASIS,
//  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  * See the License for the specific language governing permissions and
//  * limitations under the License.
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//  * The BEM markup is as per the AEM core form components guidelines.
//  * LINK- https://github.com/adobe/aem-core-forms-components/blob/master/ui.af.apps/src/main/content/jcr_root/apps/core/fd/components/form/fileinput/v1/fileinput/fileinput.html
//  ******************************************************************************
const react_1 = __importStar(require("react"));
const af_core_1 = require("@aemforms/af-core");
const withRuleEngine_1 = require("../utils/withRuleEngine");
const utils_1 = require("../utils/utils");
const FieldWrapper_1 = __importDefault(require("./common/FieldWrapper"));
const FileUpload = (props) => {
    const fileInputField = (0, react_1.useRef)(null);
    const { id, name, value, label, required, accept, maxFileSize, visible, enabled, appliedCssClassNames, properties, valid } = props;
    let val = value && (value instanceof Array ? value : [value]);
    const [files, setFiles] = (0, react_1.useState)(val || []);
    const [dragOver, setDragOver] = (0, react_1.useState)(false);
    const maxFileSizeInBytes = (0, af_core_1.getFileSizeInBytes)(maxFileSize);
    let multiple = props.type?.endsWith('[]') ? { multiple: true } : {};
    const fileChangeHandler = (0, react_1.useCallback)((files) => {
        if (multiple) {
            props.dispatchChange(files);
        }
        else {
            props.dispatchChange(files.length > 0 ? files[0] : null);
        }
    }, [multiple, props.dispatchChange]);
    const handleDragOver = (event) => {
        event.preventDefault();
        setDragOver(true);
    };
    const handleDragLeave = (event) => {
        event.preventDefault();
        setDragOver(false);
    };
    const fileUploadHandler = (0, react_1.useCallback)((e) => {
        e.preventDefault();
        const newFiles = Array.from(e.dataTransfer?.files || e?.target?.files || e.clipboardData?.files || []);
        if (newFiles?.length) {
            const validFiles = newFiles.filter((file) => file.size <= maxFileSizeInBytes);
            if (validFiles.length < newFiles.length) {
                // Show constraint message for files with size exceeding the limit
                alert(`${props.constraintMessages?.maxFileSize}`);
            }
            const updatedFiles = [...files, ...validFiles];
            setFiles(updatedFiles);
            fileChangeHandler(updatedFiles);
        }
        setDragOver(false);
    }, [files, fileChangeHandler, maxFileSizeInBytes, props?.constraintMessages]);
    const removeFile = (0, react_1.useCallback)((index) => {
        const fileList = [...files];
        fileList.splice(index, 1);
        setFiles(fileList);
        fileChangeHandler(fileList);
    }, [files, fileChangeHandler]);
    const isFilled = Array.isArray(files) ? files.length : files;
    return (react_1.default.createElement("div", { className: `cmp-adaptiveform-fileinput cmp-adaptiveform-fileinput--${isFilled ? 'filled' : 'empty'} ${appliedCssClassNames || ''}`, "data-cmp-is": "adaptiveFormFileInput", "data-cmp-visible": visible, "data-cmp-enabled": enabled, "data-cmp-required": required, "data-cmp-valid": valid },
        react_1.default.createElement(FieldWrapper_1.default, { bemBlock: "cmp-adaptiveform-fileinput", label: label, id: id, tooltip: props.tooltip, description: props.description, isError: props.isError, errorMessage: props.errorMessage },
            react_1.default.createElement("br", null),
            react_1.default.createElement("div", { className: "cmp-adaptiveform-fileinput__container" },
                react_1.default.createElement("div", { className: dragOver ? 'cmp-adaptiveform-fileinput__dragarea cmp-adaptiveform-fileinput__dragarea--active' : 'cmp-adaptiveform-fileinput__dragarea', onDragOver: handleDragOver, onDrop: fileUploadHandler, onDragLeave: handleDragLeave, onPaste: fileUploadHandler },
                    react_1.default.createElement("div", { className: "cmp-adaptiveform-fileinput__icon" }),
                    react_1.default.createElement("div", { className: "cmp-adaptiveform-fileinput__dragtext" }, properties?.dragDropText),
                    react_1.default.createElement("label", { htmlFor: id, className: "cmp-adaptiveform-fileinput__widgetlabel" }, "Attach"),
                    react_1.default.createElement("input", { ref: fileInputField, className: "cmp-adaptiveform-fileinput__widget", id: id, type: "file", name: name, onChange: fileUploadHandler, required: required, accept: accept?.toString(), multiple: true, "max-file-size": maxFileSize, style: { display: 'none' }, "aria-invalid": !valid, "aria-describedby": (0, utils_1.syncAriaDescribedBy)(id, props.tooltip, props.description, props.errorMessage) })),
                react_1.default.createElement("ul", { className: "cmp-adaptiveform-fileinput__filelist" }, files &&
                    files?.map((item, index) => (react_1.default.createElement("li", { className: "cmp-adaptiveform-fileinput__fileitem", key: item?.name },
                        react_1.default.createElement("span", { className: "cmp-adaptiveform-fileinput__filename", "aria-label": item?.name }, item?.name),
                        react_1.default.createElement("span", { className: "cmp-adaptiveform-fileinput__fileendcontainer" },
                            react_1.default.createElement("span", { className: "cmp-adaptiveform-fileinput__filesize" }, (0, utils_1.formatBytes)(item?.size)),
                            react_1.default.createElement("button", { onClick: () => removeFile(index), className: "cmp-adaptiveform-fileinput__filedelete", role: "button" }, "x"))))))))));
};
exports.default = (0, withRuleEngine_1.withRuleEngine)(FileUpload);
