"use strict";
// *******************************************************************************
//  * Copyright 2024 Adobe
//  *
//  * Licensed under the Apache License, Version 2.0 (the “License”);
//  * you may not use this file except in compliance with the License.
//  * You may obtain a copy of the License at
//  *
//  *     http://www.apache.org/licenses/LICENSE-2.0
//  *
//  * Unless required by applicable law or agreed to in writing, software
//  * distributed under the License is distributed on an “AS IS” BASIS,
//  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  * See the License for the specific language governing permissions and
//  * limitations under the License.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//  * The BEM markup is as per the AEM core form components guidelines.
//  * LINK- https://github.com/adobe/aem-core-forms-components/blob/master/ui.af.apps/src/main/content/jcr_root/apps/core/fd/components/form/recaptcha/v1/recaptcha/recaptcha.html
//  ******************************************************************************
const react_1 = __importDefault(require("react"));
const af_core_1 = require("@aemforms/af-core");
const withRuleEngine_1 = require("../utils/withRuleEngine");
const react_google_recaptcha_1 = __importDefault(require("react-google-recaptcha"));
const ReCAPTCHAComponent = (props) => {
    const { label, enabled, visible, required, valid, value, appliedCssClassNames, isError, errorMessage, dispatchChange } = props;
    const config = (0, af_core_1.getOrElse)(props, ['properties', 'fd:captcha', 'config'], {});
    const bemClass = 'cmp-adaptiveform-recaptcha';
    if (!config.siteKey) {
        return null;
    }
    return (react_1.default.createElement("div", { className: `${bemClass} ${bemClass}--${value ? 'filled' : 'empty'} ${appliedCssClassNames || ''}`, "data-cmp-is": "adaptiveFormRecaptcha", "data-cmp-visible": visible, "data-cmp-enabled": enabled, "data-cmp-required": required, "data-cmp-valid": valid, "data-testid": props.id },
        label?.visible ? react_1.default.createElement("div", { className: `${bemClass}__label` }, label.value) : null,
        react_1.default.createElement("div", { className: `${bemClass}__widget` },
            react_1.default.createElement(react_google_recaptcha_1.default, { sitekey: config.siteKey, size: config.size, theme: config.theme, type: config.type, onChange: dispatchChange })),
        isError ? react_1.default.createElement("div", { className: `${bemClass}__errormessage` }, errorMessage) : null));
};
exports.default = (0, withRuleEngine_1.withRuleEngine)(ReCAPTCHAComponent);
