"use strict";
// *******************************************************************************
//  * Copyright 2023 Adobe
//  *
//  * Licensed under the Apache License, Version 2.0 (the “License”);
//  * you may not use this file except in compliance with the License.
//  * You may obtain a copy of the License at
//  *
//  *     http://www.apache.org/licenses/LICENSE-2.0
//  *
//  * Unless required by applicable law or agreed to in writing, software
//  * distributed under the License is distributed on an “AS IS” BASIS,
//  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  * See the License for the specific language governing permissions and
//  * limitations under the License.
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
//  * The BEM markup is as per the AEM core form components guidelines.
//  * LINK- https://github.com/adobe/aem-core-forms-components/blob/master/ui.af.apps/src/main/content/jcr_root/apps/core/fd/components/form/wizard/v1/wizard/wizard.html
//  ******************************************************************************
const react_1 = __importStar(require("react"));
const af_react_renderer_1 = require("@aemforms/af-react-renderer");
const af_react_renderer_2 = require("@aemforms/af-react-renderer");
const withRuleEngine_1 = require("../utils/withRuleEngine");
const LabelWithDescription_1 = __importDefault(require("./common/LabelWithDescription"));
const Wizard = (props) => {
    // @ts-ignore
    const { mappings, form } = (0, react_1.useContext)(af_react_renderer_1.FormContext);
    const { items, label, id, visible, enabled, appliedCssClassNames } = props;
    const [activeTab, setActiveTab] = (0, react_1.useState)(0);
    const { v: visibleItems } = items.reduce(({ v }, item) => {
        const isVisible = item.visible === true;
        return {
            v: isVisible ? v.concat([item]) : v
        };
    }, { v: [] });
    const previousHandler = (0, react_1.useCallback)(() => {
        setActiveTab(activeTab - 1);
    }, [activeTab]);
    const nextHandler = (0, react_1.useCallback)(() => {
        // Get the ID of the current active child
        const activeChildId = visibleItems[activeTab]?.id;
        // Retrieve the active child model directly
        const activeChildModel = form.getElement(activeChildId);
        // Validate the current child
        const validationErrorList = activeChildModel?.validate() || [];
        // Proceed if there are no validation errors
        if (validationErrorList.length === 0) {
            setActiveTab(activeTab + 1); // Move to the next tab
        }
        else {
            // Handle validation errors
            console.log('Validation failed', validationErrorList); // Log errors for debugging
        }
    }, [activeTab, visibleItems, form]);
    const getChild = (0, react_1.useCallback)((child, index) => {
        const Comp = (0, af_react_renderer_2.getRenderer)(child, mappings);
        return Comp ? react_1.default.createElement(Comp, { key: `${child.id}_${index}`, ...child }) : (null);
    }, []);
    return visible ? (react_1.default.createElement("div", { id: id, className: `cmp-adaptiveform-wizard cmp-adaptiveform-wizard--v2 ${appliedCssClassNames || ''}`, "data-panelcontainer": "wizard", "data-placeholder-text": "Please drag Wizard components here", "data-cmp-visible": visible, "data-cmp-enabled": enabled },
        react_1.default.createElement(LabelWithDescription_1.default, { bemBlock: 'cmp-adaptiveform-wizard', label: label, id: id, tooltip: props.tooltip, description: props.description }),
        react_1.default.createElement("div", { className: "cmp-adaptiveform-wizard__widget cmp-adaptiveform-wizard__widget--v2", id: `${id}-widget` },
            react_1.default.createElement("div", { className: "cmp-adaptiveform-wizard__tabs-container" },
                react_1.default.createElement("ol", { id: `${id}_guide-item-nav-container`, className: "cmp-adaptiveform-wizard__tabList", role: "tablist" }, visibleItems.map((item, index) => (react_1.default.createElement("li", { key: item.id, title: item?.label?.value, id: `${item.id}_wizard-item-nav`, className: `cmp-adaptiveform-wizard__tab ${index === activeTab ? 'cmp-adaptiveform-wizard__tab--active' : ''}`, role: "tab", tabIndex: index === activeTab ? 0 : -1, "aria-selected": index === activeTab ? 'true' : 'false', "data-cmp-hook-adaptiveformwizard": "tab" }, item.label?.value))))),
            react_1.default.createElement("div", { className: "cmp-adaptiveform-wizard__containerNav" },
                visibleItems.length > 0 && activeTab > 0 ?
                    react_1.default.createElement("div", { className: "cmp-adaptiveform-wizard__nav cmp-adaptiveform-wizard__nav--previous", role: "navigation", "aria-label": "Previous Button", onClick: previousHandler, tabIndex: 0 })
                    : null,
                visibleItems.length > 0 && activeTab < visibleItems.length - 1 ?
                    react_1.default.createElement("div", { className: "cmp-adaptiveform-wizard__nav cmp-adaptiveform-wizard__nav--next", role: "navigation", "aria-label": "Next Button", onClick: nextHandler, tabIndex: 0 })
                    : null),
            visibleItems.length > 0 ?
                react_1.default.createElement("div", { "data-cmp-hook-adaptiveformtabs": "tabpanel", className: `cmp-adaptiveform-wizard__wizardpanel cmp-adaptiveform-wizard__wizardpanel--v2 ${activeTab === visibleItems[activeTab].index ? 'cmp-adaptiveform-wizard__wizardpanel--active' : ''}`, role: "tabpanel", tabIndex: 0, "aria-hidden": activeTab === visibleItems[activeTab].index ? 'false' : 'true', "aria-labelledby": `${visibleItems[activeTab].id}_wizard-item-nav`, "data-cmp-hook-adaptiveformwizard": "wizardpanel" }, getChild(visibleItems[activeTab], activeTab))
                : null))) : null;
};
exports.default = (0, withRuleEngine_1.withRuleEnginePanel)(Wizard);
